package com.ascendfinalproject.warehouse.kafkaservice;

import com.ascendfinalproject.warehouse.models.WarehouseOrder;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;
import reactor.kafka.sender.KafkaSender;
import reactor.kafka.sender.SenderRecord;
import reactor.kafka.sender.SenderResult;

@Service
@Slf4j
public class Sender {

  @Autowired
  private KafkaSender<String, Mono<WarehouseOrder>> kafkaEventProducer;

  private static final String TOPIC = "order";
  public void sendOrder(Mono<WarehouseOrder> currentOrder) {
    log.info(String.format("Sender message: %s ", currentOrder));
    ProducerRecord<String, Mono<WarehouseOrder>> record = new ProducerRecord<>(TOPIC, currentOrder);
    Flux<SenderResult<Mono<WarehouseOrder>>> working = kafkaEventProducer.send(Mono.just(SenderRecord.create(record, currentOrder)))
            .doOnError(throwable -> System.out.println(throwable))
            .doOnNext(t -> {
              if (null != t.exception()) {
                System.out.println("it works!");
              }
            });
    working.doOnError(throwable -> log.error("error")).subscribe();
  }

//  public void sendOrderStatus(String status) {
//    log.info(String.format("Sender message: %s ", status));
//    ProducerRecord<String, String> record = new ProducerRecord<>(TOPIC, status);
//    Flux<SenderResult<String>> working = kafkaEventProducer.send(Mono.just(SenderRecord.create(record, status)))
//            .doOnError(throwable -> System.out.println(throwable))
//            .doOnNext(uuidSenderResult -> {
//              if (null != uuidSenderResult.exception()) {
//                System.out.println("it works!");
//              }
//            });
//    working.doOnError(throwable -> log.error("error")).subscribe();
//  }

}
